# SheildPy: Secure Data Privacy Framework for Python Data Scientists

SheildPy is an all-in-one Python package designed to address data privacy and security concerns for data scientists. Developed by Deependra Verma, SheildPy offers robust encryption, anonymization, and access control tools, ensuring the confidentiality and integrity of sensitive data.

## Contact Information
- **Name:** Deependra Verma
- **Email:** deependra.verma00@gmail.com
- **LinkedIn:** [Deependra Verma](https://www.linkedin.com/in/deependra-verma-data-science/)
- **GitHub Profile:** [DeependraVerma](https://github.com/DeependraVerma)
- **Portfolio:** [Deependra's Portfolio](https://deependradatascience-productportfolio.netlify.app/)

## Installation

You can install SheildPy via pip:

```bash
pip install SheildPy
```

Alternatively, you can clone the GitHub repository:

```bash
git clone https://github.com/DeependraVerma/SecuPy-Secure-Data-Privacy-Framework-for-Python-Data-Scientists.git
cd SecuPy-Secure-Data-Privacy-Framework-for-Python-Data-Scientists
python setup.py install
```

## Dependencies

SheildPy relies on the following dependencies:
- `pandas>=1.0.0`
- `faker>=8.0.0`
- `cryptography>=3.0`

## Methods

SheildPy provides the following key methods:
- `encrypt_data(data)`: Encrypts sensitive data to ensure confidentiality.
- `decrypt_data(encrypted_data)`: Decrypts encrypted data to its original form.
- `anonymize_data(data, columns_to_anonymize)`: Anonymizes specific columns in a DataFrame.
- `add_role(role_name, permissions)`: Adds a new role with associated permissions to the access control system.
- `check_permission(role_name, permission)`: Checks if a role has the specified permission.

## Users Benefit

SheildPy empowers data scientists with the following benefits:
- **Data Confidentiality:** Encrypt sensitive data to prevent unauthorized access.
- **Anonymization:** Anonymize personally identifiable information for privacy protection.
- **Access Control:** Control data access based on user roles and permissions.
- **Compliance:** Ensure compliance with data protection regulations (e.g., GDPR, HIPAA).

## Use Cases

SheildPy can be used in various data science scenarios, including:
- Healthcare data analysis
- Financial data processing
- User authentication systems
- Research collaborations with external parties


## Invitation for Contribution

Contributions to SheildPy are welcome! To contribute, follow these steps:
1. Fork the repository on GitHub.
2. Clone the forked repository to your local machine.
3. Create a new branch for your changes.
4. Make your modifications and improvements.
5. Test your changes to ensure they work as expected.
6. Commit your changes and push them to your forked repository.
7. Submit a pull request to the original repository.

Let's collaborate to make SheildPy the go-to solution for secure data privacy in the Python data science community.